// commands, macros and stuff.

use crate::{errors::TexError, AsLatex, Res};

#[derive(Debug, Clone)]
pub struct Command {
    pub name: String,
    pub nargs: usize,
    pub def: String, // actual latex, cannot help
}

impl AsLatex for Command {
    fn to_string(&self) -> String {
        format!(
            "\\newcommand{{\\{}}}[{}]{{{}}} ",
            self.name, self.nargs, self.def
        )
    }
}

impl Command {
    pub fn new(name: &str, nargs: usize, def: &str) -> Self {
        Self { name: name.to_string(), nargs, def: def.to_string() }
    }

    pub fn call(&self, args: Vec<String>) -> Res<String> {
        if args.len() != self.nargs {
            return Err(TexError::ArgLen.into());
        }
        let temp = args
            .iter()
            .map(|x| format!("\\{}{{{x}}}", self.name))
            .collect::<String>();
        Ok(temp)
    }
}
